Learn R Programming

CANSIM2R (version 0.11)

mergeCANSIM: mergeCANSIM

Description

Extracts more than one CANSIM table and produces a merged table (by ID and period).

Usage

mergeCANSIM(cansimTableVector, keepUnmatched = FALSE, showLabels = TRUE)

Arguments

cansimTableVector

- vector containing all the CANSIM tables to extract and merge.

keepUnmatched

- if true, keeps all values, even if no match was found. FALSE by default.

showLabels

- show the Statistics Canada labels after finishing extracting and converting the table, TRUE by default.

Value

data frame containing CANSIM tables.

Examples

Run this code
# NOT RUN {
mergeCANSIM( c(2020501, 3260021) )
# }

Run the code above in your browser using DataLab