powered by
Extracts more than one CANSIM table and produces a merged table (by ID and period).
mergeCANSIM(cansimTableVector, keepUnmatched = FALSE, showLabels = TRUE)
- vector containing all the CANSIM tables to extract and merge.
- if true, keeps all values, even if no match was found. FALSE by default.
- show the Statistics Canada labels after finishing extracting and converting the table, TRUE by default.
data frame containing CANSIM tables.
# NOT RUN { mergeCANSIM( c(2020501, 3260021) ) # }
Run the code above in your browser using DataLab